@@ -3,13 +3,13 @@
  */
 
 rcube_webmail.prototype.contextmenu_command_handlers = new Object();
-rcube_webmail.prototype.contextmenu_disable_multi = new Array('#reply','#reply-all','#reply-list','#forward','#forward-attachment','#print','#edit','#viewsource','#download','#open','#edit');
+rcube_webmail.prototype.contextmenu_disable_multi = new Array('#reply','#reply-all','#reply-list','#forward-inline','#print','#edit','#viewsource','#download','#open','#edit');
 
 function rcm_contextmenu_update() {
-	if (!rcmail.env.flag_for_deletion && rcmail.env.trash_mailbox && rcmail.env.mailbox != rcmail.env.trash_mailbox)
-		$("#rcm_delete").html(rcmail.gettext('movemessagetotrash'));
-	else
-		$("#rcm_delete").html(rcmail.gettext('deletemessage'));
+	//if (!rcmail.env.flag_for_deletion && rcmail.env.trash_mailbox && rcmail.env.mailbox != rcmail.env.trash_mailbox)
+	//	$("#rcm_delete").html('<span>' + rcmail.gettext('movemessagetotrash') + '</span>');
+	//else
+	//	$("#rcm_delete").html('<span>' + rcmail.gettext('deletemessage') + '</span>');
 }
 
 function rcm_contextmenu_init(row) {
@@ -51,14 +51,16 @@ function rcm_contextmenu_init(row) {
 					case 'reply':
 					case 'reply-all':
 					case 'reply-list':
-					case 'forward':
+					case 'forward-inline':
 					case 'forward-attachment':
 					case 'print':
 					case 'download':
-					case 'edit':
 					case 'viewsource':
 						rcmail.command(command, '', $(el));
 						break;
+					case 'edit':
+						rcmail.command(command, 'new', $(el));
+						break;
 					case 'open':
 						rcmail.command(command, '', rcube_find_object('rcm_open'));
 						rcmail.sourcewin = window.open(rcube_find_object('rcm_open').href);
@@ -111,16 +113,19 @@ function rcm_set_dest_folder(folder) {
 	rcmail.env.rcm_destfolder = folder;
 }
 
-function rcm_contextmenu_register_command(command, callback, label, pos, sep, multi, newSub, menu) {
+function rcm_contextmenu_register_command(command, callback, label, pos, sep, multi, newSub, menu, liclass) {
 	if (!menu)
 		menu = $('#rcmContextMenu');
 
+	if (!liclass)
+		liclass = command;
+
 	if (typeof label != 'string') {
 		var menuItem = label.children('li');
 	}
 	else {
-		var menuItem = $('<li>').addClass(command);
-		$('<a>').attr('href', '#' + command).addClass('active').html(rcmail.gettext(label)).appendTo(menuItem);
+		var menuItem = $('<li>').addClass(liclass);
+		$('<a>').attr('href', '#' + command).addClass('active').html('<span>' + rcmail.gettext(label) + '</span>').appendTo(menuItem);
 	}
 
 	rcmail.contextmenu_command_handlers[command] = callback;
@@ -162,7 +167,7 @@ function rcm_contextmenu_register_command(command, callback, label, pos, sep, mu
 }
 
 function rcm_foldermenu_init() {
-	$("#mailboxlist-container li").contextMenu({
+	$("#mailboxlist li").contextMenu({
 		menu: 'rcmFolderMenu'
 	},
 	function(command, el, pos) {
@@ -305,9 +310,9 @@ function rcm_update_options(el) {
 			}
 		}
 		else if ($(el).hasClass('addressbook')) {
-			var matches = $(el).attr('id').match(/rcmli([A-Z0-9\-_]+)/i);
+			var source = $(el).children('a').attr('rel');
 
-			if (!rcmail.env.address_sources[matches[1]].readonly)
+			if (!rcmail.env.address_sources[source].readonly)
 				$('#rcmGroupMenu').enableContextMenuItems('#group-create')
 		}
 	}
@@ -319,12 +324,15 @@ function rcm_update_options(el) {
 			else
 				$('#rcmAddressMenu').enableContextMenuItems(rcmail.contextmenu_disable_multi.join(','));
 
+			if (rcmail.env.group && rcmail.contact_list.in_selection(matches[1]))
+				$('#rcmAddressMenu').enableContextMenuItems('#group-remove-selected');
+			else
+				$('#rcmAddressMenu').disableContextMenuItems('#group-remove-selected');
+
 			var ab_src = rcmail.env.source ? rcmail.env.source : matches[1].split('-', 2)[1];
 
 			if (rcmail.env.address_sources[ab_src].readonly)
-				$('#rcmAddressMenu').disableContextMenuItems('#edit,#delete');
-			else
-				$('#rcmAddressMenu').enableContextMenuItems('#edit,#delete');
+				$('#rcmAddressMenu').disableContextMenuItems('#edit,#delete,#group-remove-selected');
 		}
 	}
 }
@@ -366,6 +374,7 @@ function rcm_addressmenu_init(row) {
 					case 'compose':
 					case 'delete':
 					case 'moveto':
+					case 'group-remove-selected':
 						var ab_src = rcmail.env.source ? rcmail.env.source : matches[1].split('-', 2)[1];
 
 						if (command == 'moveto') {
@@ -501,7 +510,7 @@ function rcm_groupmenu_update(action, props) {
 				.attr('href', '#moveto')
 				.addClass('active')
 				.attr('onclick', "rcm_set_dest_book('G" + gid + "', '" + props.source + "','" + props.id + "')")
-				.html('&nbsp;&nbsp;' + props.name);
+				.html('<span>' + props.name + '</span>');
 
 			var li = $('<li>').addClass('contactgroup').append(link);
 
@@ -528,12 +537,12 @@ function rcm_groupmenu_update(action, props) {
 						.attr('href', '#moveto')
 						.addClass('active')
 						.attr('onclick', "rcm_set_dest_book('G" + new_gid + "', '" + props.source + "','" + props.newid + "')")
-						.html('&nbsp;&nbsp;' + props.name);
+						.html('<span>' + props.name + '</span>');
 
 					$('#rcm_contextgrps_G' + gid).replaceWith(link);
 				}
 				else {
-					$('#rcm_contextgrps_G' + gid).html('&nbsp;&nbsp;' + props.name);
+					$('#rcm_contextgrps_G' + gid).html('<span>' + props.name + '</span>');
 				}
 
 				row = $('#rcm_contextgrps_G' + gid).parent().clone(true);
@@ -577,7 +586,7 @@ $(document).ready(function() {
 
 		// init group list menu
 		if ($('#rcmGroupMenu').length > 0) {
-			rcmail.add_onload('rcm_groupmenu_init("#directorylistbox li");');
+			rcmail.add_onload('rcm_groupmenu_init("#directorylist li");');
 			rcmail.addEventListener('group_insert', function(props) { rcm_groupmenu_update('insert', props); } );
 			rcmail.addEventListener('group_update', function(props) { rcm_groupmenu_update('update', props); } );
 			rcmail.addEventListener('group_delete', function(props) { rcm_groupmenu_update('remove', props); } );
